<?php
/**
 * @file
 * Default data schema for ucsf_profiles table.
 */

/**
 * Implements hook_data_default().
 *
 * @return array
 *   Default tables.
 *
 * See @link http://drupal.org/project/data Data @endlink module for the
 * data.api.php file.
 */
function ucsf_profiles_data_default() {
  $data_tables = array();

  $data_table = new stdClass();
  $data_table->disabled = FALSE;
  $data_table->api_version = 1;
  $data_table->title = 'UCSF Profiles';
  $data_table->name = 'ucsf_profiles';
  $data_table->table_schema = array(
    'description' => 'Publication records for UCSF Profiles.',
    'fields' => array(
      'ucsf_id' => array(
        'description' => 'UCSF ID.',
        'type' => 'int',
        'unsigned' => TRUE,
        'not null' => TRUE,
        'default' => 0,
      ),
      'person_id' => array(
        'description' => 'Person ID.',
        'type' => 'int',
        'unsigned' => TRUE,
        'not null' => TRUE,
        'default' => 0,
      ),
      'full_name' => array(
        'description' => 'Full name.',
        'type' => 'varchar',
        'length' => '255',
        'not null' => FALSE,
        'default' => '',
      ),
      'first_name' => array(
        'description' => 'First name.',
        'type' => 'varchar',
        'length' => '255',
        'not null' => FALSE,
        'default' => '',
      ),
      'last_name' => array(
        'description' => 'Last name.',
        'type' => 'varchar',
        'length' => '255',
        'not null' => FALSE,
        'default' => '',
      ),
      'profile_url' => array(
        'description' => 'Profile URL.',
        'type' => 'varchar',
        'length' => '255',
        'not null' => FALSE,
        'default' => '',
      ),
      'pub_id' => array(
        'description' => 'The primary identifier for a publication record.',
        'type' => 'varchar',
        'length' => 36,
        'binary' => TRUE,
        'not null' => TRUE,
        'collate' => 'utf8_bin',
        'default' => '00000000-0000-0000-0000-000000000000',
      ),
      'pub_reference' => array(
        'description' => 'Publication reference.',
        'type' => 'text',
        'not null' => FALSE,
      ),
      'pub_source_url' => array(
        'description' => 'Publication source URL.',
        'type' => 'varchar',
        'length' => '255',
        'not null' => FALSE,
        'default' => '',
      ),
      'pub_source_name' => array(
        'description' => 'Publication source name.',
        'type' => 'varchar',
        'length' => '32',
        'not null' => FALSE,
        'default' => '',
      ),
    ),
    'name' => 'ucsf_profiles',
    'indexes' => array(
      'ucsf_profiles_ucsf_id'       => array('ucsf_id'),
      'ucsf_profiles_person_id'     => array('person_id'),
      'ucsf_profiles_pub_reference' => array(array('pub_reference', 255)),
    ),
    'primary key' => array('pub_id'),
  );
  $data_table->meta = array(
    'fields' => array(
      'ucsf_id' => array(
        'label' => 'UCSF ID',
      ),
      'person_id' => array(
        'label' => 'Person ID',
      ),
      'full_name' => array(
        'label' => 'Full name',
      ),
      'first_name' => array(
        'label' => 'First name',
      ),
      'last_name' => array(
        'label' => 'Last name',
      ),
      'profile_url' => array(
        'label' => 'Profile URL',
      ),
      'pub_id' => array(
        'label' => 'Publication ID',
      ),
      'pub_reference' => array(
        'label' => 'Publication reference',
      ),
      'pub_source_url' => array(
        'label' => 'Publication source URL',
      ),
      'pub_source_name' => array(
        'label' => 'Publication source name',
      ),
    ),
  );

  $data_tables['ucsf_profiles'] = $data_table;
  return $data_tables;
}
